/**
 * @file       uart.h
 * @brief      serial port communication
 * 
 * @author     laurent Saint-Marcel(lstmarcel@yahoo.fr)
 * @date       2002/09/02
 */

#ifndef __UART_H__
#define __UART_H__

#include "baseTypes.h"

/*
 * @brief UART_FULL if defined, it add functions for strings, but it takes more memory space
 */
/*#define UART_FULL*/

/**
 * @brief Byte returned by uartReceive when there is no byte received on serial port
 * @see uartReceive
 */
#define UART_NO_RCV             0x00
/**
 * @brief uartReceive waits for a byte to be received on serial port before returning
 * @see uartReceive
 */
#define UART_WAIT_RECEIVE       TRUE
/**
 * @brief uartReceive does not wait for a byte to be received on serial port before returning
 * @see uartReceive
 */
#define UART_DONT_WAIT_RECEIVE  FALSE



/*************** Baud rates defined for a 8MHz cristal ***************/
/**
 *@brief  Baud rate value 1200, to be used with uartInit
 */
#define UART_BAUD_RATE_1200		1
/**
 * @brief Baud rate value 2400, to be used with uartInit
 */
#define UART_BAUD_RATE_2400		2
/**
 * @brief Baud rate value 4800, to be used with uartInit
 */
#define UART_BAUD_RATE_4800		3
/**
 * @brief Baud rate value 9600, to be used with uartInit
 */
#define UART_BAUD_RATE_9600		51

#ifndef __cplusplus
/**
 * @brief This function initialize serial port
 * @param baud rate speed for serial port,
 * @see   BAUD_RATE_9600... 
 */
void uartInit(BYTE baud);
#else
void uartInit(BYTE baud=UART_BAUD_RATE_9600);
#endif

/**
 * @brief This function sends one byte on serial port
 */
void uartSend(BYTE data);

#ifndef __cplusplus
/**
 * @brief This function gets one byte from serial port
 * @param blocking if set to UART_DONT_WAIT_RECEIVE, if there is no byte 
 *        waiting on serial port, the function returns immediatly the value 
 *        UART_NO_RCV\n
 *        If set to UART_WAIT_RECEIVE, the function waits until a byte
 *        arrives on serial port and it returns it
 *        
 * @see UART_WAIT_RECEIVE      
 * @see UART_DONT_WAIT_RECEIVE
 * @see UART_NO_RCV
 */
BYTE uartReceive(BOOL blocking);
#else
BYTE uartReceive(BOOL blocking=UART_WAIT_RECEIVE);
#endif

#ifdef UART_FULL
#include <pgmspace.h>
void uartSendString(char* string);
void uartSendString_P(PGM_P string);
void uartIntAffiche(int nb, int l);
void uartHexAffiche(BYTE data);
#endif

#endif /* __UART_H__ */
